@@ -31,6 +31,12 @@ def mcnemar_table(y_target, y_model1, y_model2):
        b: tb[0, 1]: # of samples that model 1 got right and model 2 got wrong
        c: tb[1, 0]: # of samples that model 2 got right and model 1 got wrong
        d: tb[1, 1]: # of samples that both models predicted incorrectly
+
+    Examples
+    -----------
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/evaluate/mcnemar_table/
+
     """
     for ary in (y_target, y_model1, y_model2):
         if len(ary.shape) != 1:
@@ -108,6 +114,12 @@ def mcnemar_tables(y_target, *y_model_predictions):
         - tb[1, 0]: # of samples that model b got right and model a got wrong
         - tb[1, 1]: # of samples that both models predicted incorrectly
 
+    Examples
+    -----------
+
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/evaluate/mcnemar_tables/
+
     """
     model_lens = set()
     y_model_predictions = list(y_model_predictions)
@@ -174,6 +186,12 @@ def mcnemar(ary, corrected=True, exact=False):
         Returns the chi-squared value and the p-value;
         if `exact=True` (default: `False`), `chi2` is `None`
 
+    Examples
+    -----------
+
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/evaluate/mcnemar/
+
     """
 
     if not ary.shape == (2, 2):
