@@ -31,6 +31,12 @@ def num_combinations(n, k, with_replacement=False):
     ----------
     comb : `int`
         Number of possible combinations.
+
+    Examples
+    -----------
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/math/num_combinations/
+
     """
     if with_replacement:
         numerator = factorial(n + k - 1)
@@ -60,6 +66,11 @@ def num_permutations(n, k, with_replacement=False):
     permut : `int`
       Number of possible permutations.
 
+    Examples
+    -----------
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/math/num_permutations/
+
     """
     if with_replacement:
         permut = n**k
