@@ -49,6 +49,11 @@ def plot_linear_regression(X, y, model=LinearRegression(),
     regression_fit : tuple
         intercept, slope, corr_coeff (float, float, float)
 
+    Examples
+    -----------
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/plotting/plot_linear_regression/
+
     """
     if isinstance(X, list):
         X = np.asarray(X, dtype=np.float)
