@@ -12,7 +12,13 @@ from scipy.sparse import issparse
 
 
 class DenseTransformer(BaseEstimator):
-    """Convert a sparse array into a dense array."""
+    """
+    Convert a sparse array into a dense array.
+
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/preprocessing/DenseTransformer/
+
+    """
 
     def __init__(self, return_copy=True):
         self.return_copy = return_copy
