@@ -29,6 +29,11 @@ def minmax_scaling(array, columns, min_val=0, max_val=1):
     df_new : pandas DataFrame object.
         Copy of the array or DataFrame with rescaled columns.
 
+    Examples
+    ----------
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/preprocessing/minmax_scaling/
+
     """
     ary_new = array.astype(float)
     if len(ary_new.shape) == 1:
@@ -90,6 +95,11 @@ def standardize(array, columns=None, ddof=0, return_params=False, params=None):
     df_new : pandas DataFrame object.
         Copy of the array or DataFrame with standardized columns.
 
+    Examples
+    ----------
+    For usage examples, please see
+    http://rasbt.github.io/mlxtend/user_guide/preprocessing/standardize/
+
     """
     ary_new = array.astype(float)
     dim = ary_new.shape
