@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2017
+# Sebastian Raschka 2014-2018
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
@@ -6,6 +6,7 @@
 
 from .counter import Counter
 from .testing import assert_raises
-from .checking import check_Xy
+from .checking import check_Xy, format_kwarg_dictionaries
 
-__all__ = ["Counter", "assert_raises", "check_Xy"]
+__all__ = ["Counter", "assert_raises", "check_Xy",
+           "format_kwarg_dictionaries"]
